OccupiedEntry

Struct OccupiedEntry 

pub struct OccupiedEntry<'a, K, V> { /* private fields */ }
A handle to an occupied entry in an LruCache.

Implementations

Source

impl<'a, K: Eq + Hash + Clone, V> OccupiedEntry<'a, K, V>

pub fn key(&self) -> &K

Return a reference to the entry’s key.

pub fn get(&self) -> &V

Return a reference to the entry’s value without promoting to MRU.

Panics

Panics if the entry is no longer present (which cannot happen under normal use, since the entry was checked before constructing this handle).

pub fn remove(self) -> V

Remove the entry and return its value.

Panics

Panics if the entry is no longer present (which cannot happen under normal use).