Cache builder — ergonomic constructor for all cache policies. Cache builder — ergonomic constructor for all cache policies.
CacheBuilder lets callers configure a cache through a fluent API and
then construct the desired implementation. Optional fields (max_bytes,
n_shards) are used by the wrapper types but are not required for basic
policy caches.
Structs
- Cache
Builder - Builder for cache instances.
Enums
- Cache
Policy - The eviction policy to use.